@@ -3,13 +3,7 @@
 
 import ctypes
 import logging
-from typing import (
-    Sequence,
-    Optional,
-    Iterator,
-)
 from pypdfium2 import _pypdfium as pdfium
-from pypdfium2._helpers.constants import ViewMode
 from pypdfium2._helpers.utilities import translate_viewmode
 
 logger = logging.getLogger(__name__)
@@ -20,43 +14,39 @@ class OutlineItem:
     An entry in the table of contents ("bookmark").
     
     Parameters:
-        level:
+        level (int):
             The number of parent items.
-        title:
+        title (str):
             String of the bookmark.
-        page_index:
+        is_closed (bool):
+            Whether child items are hidden by default.
+        page_index (int):
             Zero-based index of the page the bookmark is pointing to.
-        view_mode:
+        view_mode (ViewMode):
             A mode defining how to interpret the coordinates of *view_pos*.
-        view_pos:
-            Target position on the page the viewport should jump to. It is a sequence of float values
-            in PDF points. Depending on *view_mode*, it can contain between 0 and 4 coordinates.
+        view_pos (typing.Sequence[float]):
+            Target position on the page the viewport should jump to. It is a sequence of float values in PDF points. Depending on *view_mode*, it can contain between 0 and 4 coordinates.
     """
     
     def __init__(
             self,
-            level: int = None,
-            title: str = None,
-            page_index: int = None,
-            view_mode: ViewMode = None,
-            view_pos: Sequence[float] = None,
+            level,
+            title,
+            is_closed,
+            page_index,
+            view_mode,
+            view_pos,
         ):
-        
         self.level = level
         self.title = title
+        self.is_closed = is_closed
         self.page_index = page_index
         self.view_mode = view_mode
         self.view_pos = view_pos
 
 
-def _get_toc_entry(
-        pdf: pdfium.FPDF_DOCUMENT,
-        bookmark: pdfium.FPDF_BOOKMARK,
-        level: int,
-    ) -> OutlineItem:
-    """
-    Convert a raw PDFium bookmark to an :class:`.OutlineItem`.
-    """
+def _get_toc_entry(pdf, bookmark, level):
+    """ Convert a raw PDFium bookmark to an :class:`.OutlineItem`. """
     
     # title
     t_buflen = pdfium.FPDFBookmark_GetTitle(bookmark, None, 0)
@@ -68,53 +58,52 @@ def _get_toc_entry(
     dest = pdfium.FPDFBookmark_GetDest(pdf, bookmark)
     page_index = pdfium.FPDFDest_GetDestPageIndex(pdf, dest)
     
+    # state
+    is_closed = pdfium.FPDFBookmark_GetCount(bookmark) < 0
+    
     # viewport
     n_params = ctypes.c_ulong()
     view_pos = (pdfium.FS_FLOAT * 4)()
     view_mode = pdfium.FPDFDest_GetView(dest, n_params, view_pos)
-    n_params = n_params.value
-    view_pos = list(view_pos)[:n_params]
+    view_pos = list(view_pos)[:n_params.value]
     view_mode = translate_viewmode(view_mode)
     
-    item = OutlineItem()
-    item.level = level
-    item.title = title
-    item.page_index = page_index
-    item.view_mode = view_mode
-    item.view_pos = view_pos
-    
-    return item
+    return OutlineItem(
+        level = level,
+        title = title,
+        is_closed = is_closed,
+        page_index = page_index,
+        view_mode = view_mode,
+        view_pos = view_pos,
+    )
 
 
 def get_toc(
-        pdf: pdfium.FPDF_DOCUMENT,
-        parent: Optional[pdfium.FPDF_BOOKMARK] = None,
-        level: int = 0,
-        max_depth: int = 15,
-        seen: Optional[list] = None,
-    ) -> Iterator[OutlineItem]:
+        pdf,
+        parent = None,
+        level = 0,
+        max_depth = 15,
+        seen = None,
+    ):
     """
-    Read the table of contents ("outline") of a PDF document.
+    Parse the outline ("table of contents") of a PDF document.
     
     Parameters:
-        pdf:
-            The PDFium document of which to parse the ToC.
-        max_depth:
-            The maximum recursion depth to consider when analysing the outline.
-        
+        pdf (``FPDF_DOCUMENT``):
+            The PDFium document of which to read the outline.
+        max_depth (int):
+            The maximum recursion depth to consider when analysing the table of contents.
     Yields:
         :class:`OutlineItem`
     """
     
     if level >= max_depth:
-        logger.warning("Maximum recursion depth reached.")
         return []
-    
-    bookmark = pdfium.FPDFBookmark_GetFirstChild(pdf, parent)
-    
     if seen is None:
         seen = set()
     
+    bookmark = pdfium.FPDFBookmark_GetFirstChild(pdf, parent)
+    
     while bookmark:
         
         address = ctypes.addressof(bookmark.contents)
@@ -125,7 +114,6 @@ def get_toc(
             seen.add(address)
         
         yield _get_toc_entry(pdf, bookmark, level)
-        
         yield from get_toc(
             pdf,
             parent = bookmark,
@@ -135,23 +123,3 @@ def get_toc(
         )
         
         bookmark = pdfium.FPDFBookmark_GetNextSibling(pdf, bookmark)
-
-
-def print_toc(toc) -> None:
-    """
-    Print the table of contents in a well-readable manner.
-    
-    Parameters:
-        toc:
-            The iterator of the outline to display (result of :func:`get_toc`).
-    """
-    
-    for item in toc:
-        
-        level = item.level
-        title = item.title
-        pagenum = item.page_index + 1
-        view_mode = item.view_mode
-        view_pos = item.view_pos
-        
-        print( '    '*level + "{} -> {}  # {} {}".format(title, pagenum, view_mode, view_pos) )
