@@ -10,7 +10,7 @@ bash utilities/check.sh
 bash utilities/install.sh
 python3 -m pytest tests/
 
-python3 platform_setup/update_pdfium.py
+python3 ./setupsrc/pl_setup/update_pdfium.py
 bash utilities/setup_all.sh
 
 twine check dist/*
